#line 1
#
# $Id: LWP.pm,v 1.149 2005/12/08 12:06:22 gisle Exp $

package LWP;

$VERSION = "5.805";
sub Version { $VERSION; }

require 5.005;
require LWP::UserAgent;  # this should load everything you need

1;

__END__

#line 658
